@@ -1,4 +1,4 @@
-/* $Id: panel-properties.c 27412 2008-08-01 20:19:47Z nick $
+/* $Id$
  *
  * Copyright (c) 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -766,7 +766,7 @@ drag_motion (Panel          *panel,
              GdkDragContext *context,
              int             x,
              int             y,
-             guint           time,
+             guint           time_,
              gpointer        user_data)
 {
     PanelPrivate *priv;
@@ -796,7 +796,7 @@ drag_motion (Panel          *panel,
 static void
 drag_leave (Panel          *panel,
             GdkDragContext *drag_context,
-            guint           time,
+            guint           time_,
             gpointer        user_data)
 {
     int    x, y, w, h, px, py;
@@ -1002,7 +1002,7 @@ panel_init_position (Panel *panel)
     xfce_itembar_set_maximum_size (XFCE_ITEMBAR (priv->itembar), max);
 
     if (priv->full_width > XFCE_PANEL_NORMAL_WIDTH)
-        gtk_widget_set_size_request (GTK_WIDGET (panel), w, -1);
+        gtk_widget_set_size_request (GTK_WIDGET (panel), w, h);
 
     if (!xfce_screen_position_is_floating (priv->screen_position))
     {
