@@ -1,4 +1,4 @@
-/*  $Id: launcher-dialog.c 27412 2008-08-01 20:19:47Z nick $
+/*  $Id$
  *
  *  Copyright (c) 2005-2007 Jasper Huijsmans <jasper@xfce.org>
  *  Copyright (c) 2006-2007 Nick Schermer <nick@xfce.org>
@@ -113,7 +113,6 @@ static void        launcher_dialog_save_button               (GtkWidget
                                                               LauncherDialog        *ld);
 static void        launcher_dialog_update_entries            (LauncherDialog        *ld);
 static void        launcher_dialog_update_icon               (LauncherDialog        *ld);
-static void        launcher_dialog_folder_chooser            (LauncherDialog        *ld);
 static void        launcher_dialog_command_chooser           (LauncherDialog        *ld);
 static void        launcher_dialog_icon_chooser              (LauncherDialog        *ld);
 static void        launcher_dialog_tree_update_row           (LauncherDialog        *ld,
@@ -154,6 +153,7 @@ launcher_dialog_read_desktop_file (const gchar   *path,
     XfceRc      *rc = NULL;
     const gchar *value = NULL;
     const gchar *p;
+    gchar       *tmp;
 
     /* we only support .desktop files */
     if (G_UNLIKELY (g_str_has_suffix (path, ".desktop") == FALSE ||
@@ -196,6 +196,15 @@ launcher_dialog_read_desktop_file (const gchar   *path,
             entry->icon = g_strndup (value, p-value);
         else
             entry->icon = g_strdup (value);
+            
+#if LAUNCHER_NEW_TOOLTIP_API
+        /* release the cached icon */
+        if (entry->tooltip_cache)
+        {
+            g_object_unref (G_OBJECT (entry->tooltip_cache));
+            entry->tooltip_cache = NULL;
+        }
+#endif
     }
 
     /* exec */
@@ -204,8 +213,10 @@ launcher_dialog_read_desktop_file (const gchar   *path,
     {
         g_free (entry->exec);
 
-        /* expand variables and store */
-        entry->exec = value ? xfce_expand_variables (value, NULL) : NULL;
+        /* expand and quote command and store */
+        tmp = xfce_expand_variables (value, NULL);
+        entry->exec = g_shell_quote (tmp);
+        g_free (tmp);
     }
 
     /* working directory */
@@ -215,7 +226,7 @@ launcher_dialog_read_desktop_file (const gchar   *path,
         g_free (entry->path);
 
         /* expand variables and store */
-        entry->path = value ? xfce_expand_variables (value, NULL) : NULL;
+        entry->path = xfce_expand_variables (value, NULL);
     }
 
     /* terminal */
@@ -241,7 +252,7 @@ launcher_dialog_tree_drag_data_received (GtkWidget        *widget,
                                          gint              y,
                                          GtkSelectionData *selection_data,
                                          guint             info,
-                                         guint             time,
+                                         guint             time_,
                                          LauncherDialog   *ld)
 {
     GtkTreePath             *path = NULL;
@@ -366,7 +377,7 @@ launcher_dialog_tree_drag_data_received (GtkWidget        *widget,
         gtk_tree_path_free (path);
 
     /* finish drag */
-    gtk_drag_finish (context, TRUE, FALSE, time);
+    gtk_drag_finish (context, TRUE, FALSE, time_);
 }
 
 
@@ -378,7 +389,7 @@ launcher_dialog_frame_drag_data_received (GtkWidget        *widget,
                                           gint              y,
                                           GtkSelectionData *selection_data,
                                           guint             info,
-                                          guint             time,
+                                          guint             time_,
                                           LauncherDialog   *ld)
 {
     GSList   *filenames, *li;
@@ -421,7 +432,7 @@ launcher_dialog_frame_drag_data_received (GtkWidget        *widget,
     }
 
     /* finish drag */
-    gtk_drag_finish (context, TRUE, FALSE, time);
+    gtk_drag_finish (context, TRUE, FALSE, time_);
 }
 
 
@@ -434,41 +445,53 @@ launcher_dialog_save_entry (GtkWidget      *entry,
                             LauncherDialog *ld)
 {
     const gchar *text;
+    gchar       *filename;
 
     /* quit if locked or no active entry set */
     if (G_UNLIKELY (ld->updating == TRUE || ld->entry == NULL))
         return;
 
-    /* get entry text */
-    text = gtk_entry_get_text (GTK_ENTRY (entry));
-
-    /* set text to null, if there is no valid text */
-    if (G_UNLIKELY (text == NULL || *text == '\0'))
-        text = NULL;
-
-    /* save new value */
-    if (entry == ld->entry_name)
+    /* handle working directory changes */
+    if (entry == ld->entry_path)
     {
-        g_free (ld->entry->name);
-        ld->entry->name = g_strdup (text);
-
-        /* update tree, when triggered by widget */
-        launcher_dialog_tree_update_row (ld, COLUMN_NAME);
+        filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (ld->entry_path));
+        if (exo_str_is_equal (ld->entry->path, filename) == FALSE)
+        {
+            g_free (ld->entry->path);
+            ld->entry->path = filename;
+        }
+        else
+        {
+            g_free (filename);
+            return;
+        }
     }
-    else if (entry == ld->entry_comment)
+    else
     {
-        g_free (ld->entry->comment);
-        ld->entry->comment = g_strdup (text);
-    }
-    else if (entry == ld->entry_exec)
-    {
-        g_free (ld->entry->exec);
-        ld->entry->exec = text ? xfce_expand_variables (text, NULL) : NULL;
-    }
-    else if (entry == ld->entry_path)
-    {
-        g_free (ld->entry->path);
-        ld->entry->path = text ? xfce_expand_variables (text, NULL) : NULL;
+        /* set text to null, if there is no valid text */
+        text = gtk_entry_get_text (GTK_ENTRY (entry));
+        if (G_UNLIKELY (text == NULL || *text == '\0'))
+            text = NULL;
+
+        /* save new value */
+        if (entry == ld->entry_name)
+        {
+            g_free (ld->entry->name);
+            ld->entry->name = g_strdup (text);
+
+            /* update tree, when triggered by widget */
+            launcher_dialog_tree_update_row (ld, COLUMN_NAME);
+        }
+        else if (entry == ld->entry_comment)
+        {
+            g_free (ld->entry->comment);
+            ld->entry->comment = g_strdup (text);
+        }
+        else if (entry == ld->entry_exec)
+        {
+            g_free (ld->entry->exec);
+            ld->entry->exec = text ? xfce_expand_variables (text, NULL) : NULL;
+        }
     }
 
     /* update panel */
@@ -509,6 +532,8 @@ launcher_dialog_save_button (GtkWidget      *button,
 static void
 launcher_dialog_update_entries (LauncherDialog *ld)
 {
+    gchar *dir;
+    
     /* quit if locked or no active entry set */
     if (G_UNLIKELY (ld->updating == TRUE || ld->entry == NULL))
         return;
@@ -526,8 +551,15 @@ launcher_dialog_update_entries (LauncherDialog *ld)
     gtk_entry_set_text (GTK_ENTRY (ld->entry_exec),
                         (ld->entry->exec != NULL) ? ld->entry->exec : "");
 
-    gtk_entry_set_text (GTK_ENTRY (ld->entry_path),
-                        (ld->entry->path != NULL) ? ld->entry->path : "");
+    if (ld->entry->path != NULL)
+      dir = ld->entry->path;
+    else
+      dir = g_get_current_dir ();
+
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (ld->entry_path), dir);
+
+    if (dir != ld->entry->path)
+      g_free (dir);
 
     /* set toggle buttons */
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (ld->entry_terminal),
@@ -588,48 +620,6 @@ launcher_dialog_update_icon (LauncherDialog *ld)
 /**
  * Icon and command search dialogs
  **/
-static void
-launcher_dialog_folder_chooser (LauncherDialog *ld)
-{
-    GtkWidget *chooser;
-    gchar     *path;
-
-    chooser = gtk_file_chooser_dialog_new (_("Select a Directory"),
-                                           GTK_WINDOW (gtk_widget_get_toplevel (ld->treeview)),
-                                           GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                                           GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-                                           GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-                                           NULL);
-
-    /* only here */
-    gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (chooser), TRUE);
-
-    /* use the bindir as default folder */
-    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser), BINDIR);
-
-    /* select folder from field */
-    if (G_LIKELY (ld->entry->path != NULL))
-    {
-        if (G_LIKELY (g_path_is_absolute (ld->entry->path)))
-            gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (chooser), ld->entry->path);
-    }
-
-    /* run the chooser dialog */
-    if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_ACCEPT)
-    {
-        path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
-
-        /* set the new entry text */
-        gtk_entry_set_text (GTK_ENTRY (ld->entry_path), path);
-
-        /* cleanup */
-        g_free (path);
-    }
-
-    /* destroy dialog */
-    gtk_widget_destroy (chooser);
-}
-
 static void
 launcher_dialog_command_chooser (LauncherDialog *ld)
 {
@@ -732,7 +722,11 @@ launcher_dialog_command_chooser (LauncherDialog *ld)
     /* run the chooser dialog */
     if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_ACCEPT)
     {
+        /* get the filename and quote it */
         filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
+        s = g_shell_quote (filename);
+        g_free (filename);
+        filename = s;
 
         /* set the new entry text */
         gtk_entry_set_text (GTK_ENTRY (ld->entry_exec), filename);
@@ -758,9 +752,8 @@ launcher_dialog_icon_chooser (LauncherDialog *ld)
     /* determine the name of the entry being edited */
     name = gtk_entry_get_text (GTK_ENTRY (ld->entry_name));
     if (G_UNLIKELY (name == NULL || *name == '\0'))
-        name = _("Unknown");
+        name = _("Unnamed");
 
-    /* allocate the chooser dialog */
     title = g_strdup_printf (_("Select an Icon for \"%s\""), name);
     chooser = exo_icon_chooser_dialog_new (title, NULL,
                                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -784,6 +777,15 @@ launcher_dialog_icon_chooser (LauncherDialog *ld)
         /* set new icon */
         ld->entry->icon = exo_icon_chooser_dialog_get_icon (EXO_ICON_CHOOSER_DIALOG (chooser));
 
+#if LAUNCHER_NEW_TOOLTIP_API
+        /* release cached tooltip icon */
+        if (ld->entry->tooltip_cache)
+        {
+            g_object_unref (G_OBJECT (ld->entry->tooltip_cache));
+            ld->entry->tooltip_cache = NULL;
+        }
+#endif
+
         /* update the icon button */
         launcher_dialog_update_icon (ld);
 
@@ -838,7 +840,7 @@ launcher_dialog_tree_update_row (LauncherDialog *ld,
                 break;
 
             case COLUMN_NAME:
-                /* build name */
+                /* TRANSLATORS: Fallback name for a launcher item without a name */
                 name = ld->entry->name ? ld->entry->name : _("Unnamed");
             
                 /* set new name */
@@ -1114,10 +1116,10 @@ launcher_dialog_add_properties (LauncherDialog *ld)
     sg = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 
     /* entry name field */
-    hbox = gtk_hbox_new (FALSE, BORDER);
+    hbox = gtk_hbox_new (FALSE, BORDER * 2);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new_with_mnemonic (_("_Name"));
+    label = gtk_label_new_with_mnemonic (_("_Name:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
@@ -1132,10 +1134,10 @@ launcher_dialog_add_properties (LauncherDialog *ld)
                       G_CALLBACK (launcher_dialog_save_entry), ld);
 
     /* entry comment field */
-    hbox = gtk_hbox_new (FALSE, BORDER);
+    hbox = gtk_hbox_new (FALSE, BORDER * 2);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new_with_mnemonic (_("_Description"));
+    label = gtk_label_new_with_mnemonic (_("_Description:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
@@ -1151,10 +1153,10 @@ launcher_dialog_add_properties (LauncherDialog *ld)
                       G_CALLBACK (launcher_dialog_save_entry), ld);
 
     /* entry icon chooser button */
-    hbox = gtk_hbox_new (FALSE, BORDER);
+    hbox = gtk_hbox_new (FALSE, BORDER * 2);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new_with_mnemonic (_("_Icon"));
+    label = gtk_label_new_with_mnemonic (_("_Icon:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
@@ -1169,10 +1171,10 @@ launcher_dialog_add_properties (LauncherDialog *ld)
                               G_CALLBACK (launcher_dialog_icon_chooser), ld);
 
     /* entry command field and button */
-    hbox = gtk_hbox_new (FALSE, BORDER);
+    hbox = gtk_hbox_new (FALSE, BORDER * 2);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new_with_mnemonic (_("Co_mmand"));
+    label = gtk_label_new_with_mnemonic (_("Co_mmand:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
@@ -1196,34 +1198,29 @@ launcher_dialog_add_properties (LauncherDialog *ld)
     gtk_container_add (GTK_CONTAINER (button), image);
 
     /* working directory field */
-    hbox = gtk_hbox_new (FALSE, BORDER);
+    hbox = gtk_hbox_new (FALSE, BORDER * 2);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
-    label = gtk_label_new_with_mnemonic (_("_Working Directory"));
+    label = gtk_label_new_with_mnemonic (_("_Working Directory:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
     gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
     gtk_size_group_add_widget (sg, label);
 
-    ld->entry_path = gtk_entry_new ();
+    ld->entry_path = gtk_file_chooser_button_new (_("Select a Working Directory"), GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
     gtk_box_pack_start (GTK_BOX (hbox), ld->entry_path, TRUE, TRUE, 0);
-
     gtk_label_set_mnemonic_widget (GTK_LABEL (label), ld->entry_path);
 
-    g_signal_connect (G_OBJECT (ld->entry_path), "changed",
+#if 0 /* GTK_CHECK_VERSION (2, 12, 0) */
+    g_signal_connect (G_OBJECT (ld->entry_path), "file-set",
                       G_CALLBACK (launcher_dialog_save_entry), ld);
-
-    button = gtk_button_new ();
-    gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
-
-    g_signal_connect_swapped (G_OBJECT (button), "clicked",
-                              G_CALLBACK (launcher_dialog_folder_chooser), ld);
-
-    image = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU);
-    gtk_container_add (GTK_CONTAINER (button), image);
+#else
+    g_signal_connect (G_OBJECT (ld->entry_path), "selection-changed",
+                      G_CALLBACK (launcher_dialog_save_entry), ld);
+#endif
 
     /* entry terminal toggle button with spacer */
-    hbox = gtk_hbox_new (FALSE, BORDER);
+    hbox = gtk_hbox_new (FALSE, BORDER * 2);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_alignment_new (0, 0, 0, 0);
@@ -1239,7 +1236,7 @@ launcher_dialog_add_properties (LauncherDialog *ld)
 
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
     /* startup notification */
-    hbox = gtk_hbox_new (FALSE, BORDER);
+    hbox = gtk_hbox_new (FALSE, BORDER * 2);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
     label = gtk_alignment_new (0, 0, 0, 0);
@@ -1337,7 +1334,6 @@ launcher_dialog_add_tree (LauncherDialog *ld)
             /* load icon */
             icon = launcher_utility_load_pixbuf (gtk_widget_get_screen (ld->treeview), entry->icon, LAUNCHER_TREE_ICON_SIZE);
             
-            /* build name */
             name = entry->name ? entry->name : _("Unnamed");
 
             /* create new row and add the data */
@@ -1484,6 +1480,9 @@ launcher_dialog_response (GtkWidget      *dialog,
         /* add new item if there are no entries yet */
         if (G_UNLIKELY (g_list_length (launcher->entries) == 0))
             launcher->entries = g_list_append (launcher->entries, launcher_entry_new ());
+        
+        /* rebuild the plugin */
+        launcher_plugin_rebuild (launcher, TRUE);
     }
 
     /* free the panel structure */
@@ -1519,8 +1518,7 @@ launcher_dialog_show (LauncherPlugin  *launcher)
     ld->stored_move_first = launcher->move_first;
     launcher->move_first = FALSE;
 
-    /* create new dialog */
-    dialog = xfce_titled_dialog_new_with_buttons (_("Program Launcher"),
+    dialog = xfce_titled_dialog_new_with_buttons (_("Launcher"),
                                                   NULL,
                                                   GTK_DIALOG_NO_SEPARATOR,
                                                   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
@@ -1528,7 +1526,7 @@ launcher_dialog_show (LauncherPlugin  *launcher)
                                                   NULL);
     gtk_window_set_screen (GTK_WINDOW (dialog), gtk_widget_get_screen (GTK_WIDGET (launcher->panel_plugin)));
     gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
-    gtk_window_set_icon_name (GTK_WINDOW (dialog), "xfce4-settings");
+    gtk_window_set_icon_name (GTK_WINDOW (dialog), GTK_STOCK_PROPERTIES);
     gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
 
     /* connect dialog to plugin, so we can destroy it when plugin is closed */
@@ -1539,7 +1537,7 @@ launcher_dialog_show (LauncherPlugin  *launcher)
     /* added the horizontal panes */
     paned = gtk_hpaned_new ();
     gtk_box_pack_start (GTK_BOX (dialog_vbox), paned, TRUE, TRUE, 0);
-    gtk_container_set_border_width (GTK_CONTAINER (paned), BORDER - 2);
+    gtk_container_set_border_width (GTK_CONTAINER (paned), BORDER);
 
     vbox = gtk_vbox_new (FALSE, BORDER);
     gtk_paned_pack1 (GTK_PANED (paned), vbox, FALSE, FALSE);
@@ -1548,6 +1546,8 @@ launcher_dialog_show (LauncherPlugin  *launcher)
     hbox = gtk_hbox_new (FALSE, BORDER);
     gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
+    /* TRANSLATORS: Arrow position for a launcher with > 1 item. Keep this
+       string as short as possible. */
     label = gtk_label_new_with_mnemonic (_("A_rrow:"));
     gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
