@@ -1,4 +1,4 @@
-/*      $Id: compositor.c 28059 2008-10-06 19:48:39Z olivier $
+/*      $Id$
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
         xcompmgr - (c) 2003 Keith Packard
         metacity - (c) 2003, 2004 Red Hat, Inc.
-        xfwm4    - (c) 2005-2008 Olivier Fourdan
+        xfwm4    - (c) 2005-2009 Olivier Fourdan
 
 */
 
@@ -50,15 +50,15 @@
 #include <X11/extensions/Xrender.h>
 
 #ifndef SHADOW_RADIUS
-#define SHADOW_RADIUS   6
+#define SHADOW_RADIUS   12
 #endif /* SHADOW_RADIUS */
 
 #ifndef SHADOW_OFFSET_X
-#define SHADOW_OFFSET_X (SHADOW_RADIUS * -3 /2)
+#define SHADOW_OFFSET_X (-3 * SHADOW_RADIUS / 2)
 #endif /* SHADOW_OFFSET_X */
 
 #ifndef SHADOW_OFFSET_Y
-#define SHADOW_OFFSET_Y (SHADOW_RADIUS * -5 / 4)
+#define SHADOW_OFFSET_Y (-3 * SHADOW_RADIUS / 2)
 #endif /* SHADOW_OFFSET_Y */
 
 /* Some convenient macros */
